Stan Math Library: stan/math/prim/mat/fun/transpose.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

transpose.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_TRANSPOSE_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_TRANSPOSE_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5
6 namespace stan {
7 namespace math {
8
9 template <typename T, int R, int C>
10 Eigen::Matrix<T, C, R>
11 inline
12 transpose(const Eigen::Matrix<T, R, C>& m) {
13 return m.transpose();
14 }
15
16 }
17 }
18 #endif
stan
Definition: log_sum_exp.hpp:8
Eigen.hpp
stan::math::transpose
Eigen::Matrix< T, C, R > transpose(const Eigen::Matrix< T, R, C > &m)
Definition: transpose.hpp:12

[ Stan Home Page ] © 2011–2016, Stan Development Team.